from setuptools import setup

setup(name='normally_dist',
      version='0.5',
      description='Gaussian and Binomial distributions',
      packages=['normally_dist'],
      author = 'Ifenna Okoye',
      zip_safe=False)
